@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 # Copyright 2015 Mirantis Inc.
 # All Rights Reserved.
 #
@@ -170,3 +171,23 @@ class ShareNetworksReadWriteTest(base.BaseTestCase):
             filters=filters)
 
         self.assertGreater(len(share_networks), 0)
+
+    def test_list_share_networks_by_inexact_unicode_option(self):
+        self.create_share_network(
+            name=u'网络名称',
+            description=u'网络描述',
+            neutron_net_id='fake_neutron_net_id',
+            neutron_subnet_id='fake_neutron_subnet_id',
+        )
+
+        filters = {'name~': u'名称'}
+        share_networks = self.admin_client.list_share_networks(
+            filters=filters)
+
+        self.assertGreater(len(share_networks), 0)
+
+        filters = {'description~': u'描述'}
+        share_networks = self.admin_client.list_share_networks(
+            filters=filters)
+
+        self.assertGreater(len(share_networks), 0)
