@@ -233,7 +233,8 @@ class FakeHTTPClient(fakes.FakeHTTPClient):
                          "rel": "self"},
                     ],
                 },
-            ]
+            ],
+            'count': 2,
         }
         return (200, {}, shares)
 
@@ -830,6 +831,13 @@ class FakeHTTPClient(fakes.FakeHTTPClient):
     def get_types_default(self, **kw):
         return self.get_types_1(**kw)
 
+    def get_types_1234(self, **kw):
+        return (200, {}, {
+            'share_type': {'id': 1,
+                           'name': 'test-type-1',
+                           'extra_specs': {'test': 'test'},
+                           'required_extra_specs': {'test': 'test'}}})
+
     def get_types(self, **kw):
         return (200, {}, {
             'share_types': [{'id': 1,
@@ -885,6 +893,7 @@ class FakeHTTPClient(fakes.FakeHTTPClient):
             'share_type': {
                 'id': 3,
                 'name': 'test-type-3',
+                'description': 'test description',
                 'extra_specs': share_type['extra_specs'],
                 'required_extra_specs': required_extra_specs,
             }
